==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/is.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Deilt með þér",
    "Shared with others" : "Deilt með öðrum",
    "Shared by link" : "Deilt með tengli",
    "Nothing shared with you yet" : "Engu deilt með þér ennþá",
    "Files and folders others share with you will show up here" : "Skrár og möppur sem aðrir deila með þér birtast hér",
    "Nothing shared yet" : "Engu deilt ennþá",
    "Files and folders you share will show up here" : "Skrár og möppur sem þú deilir birtast hér",
    "No shared links" : "Engir sameignartenglar",
    "Files and folders you share by link will show up here" : "Skrár og möppur sem þú deilir með tenglum birtast hér",
    "You can upload into this folder" : "Þú getur sent inn skrár í þessa möppu",
    "No compatible server found at {remote}" : "Enginn samhæfður vefþjónn fannst á {remote}",
    "Invalid server URL" : "Ógild URI-slóð vefþjóns",
    "Failed to add the public link to your Nextcloud" : "Mistókst að bæta opinberum tengli í þitt eigið Nextcloud",
    "Share" : "Deila",
    "No expiration date set" : "Engin dagsetning fyrir gildistíma er sett",
    "Shared by" : "Deilt af",
    "Sharing" : "Deiling",
    "File shares" : "Skráasameignir",
    "Downloaded via public link" : "Náð í með almenningstengli",
    "Downloaded by {email}" : "Náð í með {email}",
    "{file} downloaded via public link" : "{file} sótt með almenningstengli",
    "{email} downloaded {file}" : "{email} sótti {file}",
    "Shared with group {group}" : "Deilt með hópnum {group}",
    "Removed share for group {group}" : "Fjarlægði sameign af hópnum {group}",
    "{actor} shared with group {group}" : "{actor} deildi með hópnum {group}",
    "{actor} removed share for group {group}" : "{actor} fjarlægði sameign af hópnum {group}",
    "You shared {file} with group {group}" : "Þú deildir {file} með hópnum {group}",
    "You removed group {group} from {file}" : "Þú fjarlægðir hópinn {group} af {file}",
    "{actor} shared {file} with group {group}" : "{actor} deildi {file} með hópnum {group}",
    "{actor} removed group {group} from {file}" : "{actor} fjarlægði hópinn {group} af {file}",
    "Shared as public link" : "Deilt sem almenningstengill",
    "Removed public link" : "Fjarlægði almenningstengil",
    "Public link expired" : "Almenningstengill er útrunninn",
    "{actor} shared as public link" : "{actor} deildi sem almenningstengill",
    "{actor} removed public link" : "{actor} fjarlægði almenningstengil",
    "Public link of {actor} expired" : "Almenningstengill {actor} er útrunninn",
    "You shared {file} as public link" : "Þú deildir {file} sem almenningstengli",
    "You removed public link for {file}" : "Þú fjarlægðir almenningstengilinn fyrir {file}",
    "Public link expired for {file}" : "Almenningstengill er útrunninn fyrir {file}",
    "{actor} shared {file} as public link" : "{actor} deildi {file} sem almenningstengli",
    "{actor} removed public link for {file}" : "{actor} fjarlægði almenningstengil fyrir {file}",
    "Public link of {actor} for {file} expired" : "Almenningstengill frá {actor} fyrir {file} er útrunninn",
    "{user} accepted the remote share" : "{user} samþykkti fjartengda sameign",
    "{user} declined the remote share" : "{user} hafnaði fjartengdri sameign",
    "You received a new remote share {file} from {user}" : "Þú tókst við nýrri fjartengdri sameign {file} frá {user}",
    "{user} accepted the remote share of {file}" : "{user} samþykkti fjartengdu sameignina {file}",
    "{user} declined the remote share of {file}" : "{user} hafnaði fjartengdu sameigninni {file}",
    "{user} unshared {file} from you" : "{user} tók af deilingu á {file} frá þér",
    "Shared with {user}" : "Deilt með {user}",
    "Removed share for {user}" : "Fjarlægði deilingu með {user}",
    "{actor} shared with {user}" : "{actor} deildi með {user}",
    "{actor} removed share for {user}" : "{actor} fjarlægði deilingu með {user}",
    "Shared by {actor}" : "Deilt af {actor}",
    "{actor} removed share" : "{actor} fjarlægði deilingu",
    "You shared {file} with {user}" : "Þú deildir {file} með {user}",
    "You removed {user} from {file}" : "Þú fjarlægðir {user} af {file}",
    "{actor} shared {file} with {user}" : "{actor} deildi {file} með {user}",
    "{actor} removed {user} from {file}" : "{actor} fjarlægði {user} af {file}",
    "{actor} shared {file} with you" : "{actor} deildi {file} með þér",
    "{actor} removed you from {file}" : "{actor} fjarlægði þig af {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Skrá eða mappa sem deilt var með tölvupósti eða almenningstengli var <strong>sótt</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Skjali eða möppu hefur verið deilt <strong>frá öðrum þjóni</strong>",
    "A file or folder has been <strong>shared</strong>" : "Skjali eða  möppu hefur verið <strong>deilt</strong>",
    "Wrong share ID, share doesn't exist" : "Rangt auðkenni sameignar, sameign er ekki til",
    "could not delete share" : "tókst ekki að eyða sameign",
    "Could not delete share" : "Tókst ekki að eyða sameign",
    "Please specify a file or folder path" : "Tiltaktu skrá eða slóð á möppu",
    "Wrong path, file/folder doesn't exist" : "Röng slóð, skrá/mappa er ekki til",
    "Could not create share" : "Ekki tókst að búa til sameign",
    "invalid permissions" : "Ógildar aðgangsheimildir",
    "Please specify a valid user" : "Settu inn gilt notandanafn",
    "Group sharing is disabled by the administrator" : "Deiling innan hóps hefur verið gerð óvirk af kerfisstjóra.",
    "Please specify a valid group" : "Settu inn gildan hóp",
    "Public link sharing is disabled by the administrator" : "Deiling opinberra sameignartengla hefur verið gerð óvirk af kerfisstjóra.",
    "Public upload disabled by the administrator" : "Opinber innsending hefur verið gerð óvirk af kerfisstjóra.",
    "Public upload is only possible for publicly shared folders" : "Opinber innsending er einungis möguleg í möppur sem er deilt opinberlega",
    "Invalid date, date format must be YYYY-MM-DD" : "Ógild dagsetning, dagsetningasniðið verður að vera ÁÁÁÁ-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Deiling %s mistókst, því bakvinnslukerfið leyfir ekki sameignir af gerðinni %s",
    "You cannot share to a Circle if the app is not enabled" : "Þú getur ekki deilt með hring ef forritið er ekki virkt",
    "Please specify a valid circle" : "Settu inn gildan hring",
    "Unknown share type" : "Óþekkt tegund sameignar",
    "Not a directory" : "Er ekki mappa",
    "Could not lock path" : "Gat ekki læst slóð",
    "Wrong or no update parameter given" : "Rangt eða ekkert uppfærsluviðfang gefið",
    "Can't change permissions for public share links" : "Ekki tókst að breyta aðgangsheimildum fyrir opinbera deilingartengla",
    "Cannot increase permissions" : "Get ekki aukið aðgangsheimildir",
    "shared by %s" : "Deilt af %s",
    "Download" : "Niðurhal",
    "Direct link" : "Beinn tengill",
    "Add to your Nextcloud" : "Bæta í þitt eigið Nextcloud",
    "Share API is disabled" : "Deilingar-API er óvirkt",
    "File sharing" : "Skráadeiling",
    "This share is password-protected" : "Þessi sameign er varin með lykilorði",
    "The password is wrong. Try again." : "Lykilorðið er rangt. Reyndu aftur.",
    "Password" : "Lykilorð",
    "No entries found in this folder" : "Engar skrár fundust í þessari möppu",
    "Name" : "Nafn",
    "Share time" : "Deilingartími",
    "Expiration date" : "Gildir til",
    "Sorry, this link doesn’t seem to work anymore." : "Því miður, þessi tengill virðist ekki virka lengur.",
    "Reasons might be:" : "Mögulegar ástæður gætu verið:",
    "the item was removed" : "atriðið var fjarlægt",
    "the link expired" : "tengillinn er útrunninn",
    "sharing is disabled" : "slökkt er á skráadeilingu",
    "For more info, please ask the person who sent this link." : "Til að vita meira skaltu hafa samband við þann sem sendi þér þennan tengil.",
    "Download %s" : "Sækja %s",
    "Upload files to %s" : "Senda inn skrár á %s",
    "Select or drop files" : "Veldu eða slepptu skrám",
    "Uploading files…" : "Sendi inn skrár…",
    "Uploaded files:" : "Innsendar skrár:",
    "%s is publicly shared" : "%s er deilt opinberlega"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/is.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with others" : "Deilt með öðrum",
    "Shared with you" : "Deilt með þér",
    "Shared by link" : "Deilt með tengli",
    "Nothing shared with you yet" : "Engu deilt með þér ennþá",
    "Files and folders others share with you will show up here" : "Skrár og möppur sem aðrir deila með þér birtast hér",
    "Nothing shared yet" : "Engu deilt ennþá",
    "Files and folders you share will show up here" : "Skrár og möppur sem þú deilir birtast hér",
    "No shared links" : "Engir sameignartenglar",
    "Files and folders you share by link will show up here" : "Skrár og möppur sem þú deilir með tenglum birtast hér",
    "You can upload into this folder" : "Þú getur sent inn skrár í þessa möppu",
    "No compatible server found at {remote}" : "Enginn samhæfður vefþjónn fannst á {remote}",
    "Invalid server URL" : "Ógild URI-slóð vefþjóns",
    "Failed to add the public link to your Nextcloud" : "Mistókst að bæta opinberum tengli í þitt eigið Nextcloud",
    "Share" : "Deila",
    "No expiration date set" : "Engin dagsetning fyrir gildistíma er sett",
    "Shared by" : "Deilt af",
    "Sharing" : "Deiling",
    "File shares" : "Skráasameignir",
    "Downloaded via public link" : "Náð í með almenningstengli",
    "Downloaded by {email}" : "Náð í með {email}",
    "{file} downloaded via public link" : "{file} sótt með almenningstengli",
    "{email} downloaded {file}" : "{email} sótti {file}",
    "Shared with group {group}" : "Deilt með hópnum {group}",
    "Removed share for group {group}" : "Fjarlægði sameign af hópnum {group}",
    "{actor} shared with group {group}" : "{actor} deildi með hópnum {group}",
    "{actor} removed share for group {group}" : "{actor} fjarlægði sameign af hópnum {group}",
    "You shared {file} with group {group}" : "Þú deildir {file} með hópnum {group}",
    "You removed group {group} from {file}" : "Þú fjarlægðir hópinn {group} af {file}",
    "{actor} shared {file} with group {group}" : "{actor} deildi {file} með hópnum {group}",
    "{actor} removed group {group} from {file}" : "{actor} fjarlægði hópinn {group} af {file}",
    "Shared as public link" : "Deilt sem almenningstengill",
    "Removed public link" : "Fjarlægði almenningstengil",
    "Public link expired" : "Almenningstengill er útrunninn",
    "{actor} shared as public link" : "{actor} deildi sem almenningstengill",
    "{actor} removed public link" : "{actor} fjarlægði almenningstengil",
    "Public link of {actor} expired" : "Almenningstengill {actor} er útrunninn",
    "You shared {file} as public link" : "Þú deildir {file} sem almenningstengli",
    "You removed public link for {file}" : "Þú fjarlægðir almenningstengilinn fyrir {file}",
    "Public link expired for {file}" : "Almenningstengill er útrunninn fyrir {file}",
    "{actor} shared {file} as public link" : "{actor} deildi {file} sem almenningstengli",
    "{actor} removed public link for {file}" : "{actor} fjarlægði almenningstengil fyrir {file}",
    "Public link of {actor} for {file} expired" : "Almenningstengill frá {actor} fyrir {file} er útrunninn",
    "{user} accepted the remote share" : "{user} samþykkti fjartengda sameign",
    "{user} declined the remote share" : "{user} hafnaði fjartengdri sameign",
    "You received a new remote share {file} from {user}" : "Þú tókst við nýrri fjartengdri sameign {file} frá {user}",
    "{user} accepted the remote share of {file}" : "{user} samþykkti fjartengdu sameignina {file}",
    "{user} declined the remote share of {file}" : "{user} hafnaði fjartengdu sameigninni {file}",
    "{user} unshared {file} from you" : "{user} tók af deilingu á {file} frá þér",
    "Shared with {user}" : "Deilt með {user}",
    "Removed share for {user}" : "Fjarlægði deilingu með {user}",
    "{actor} shared with {user}" : "{actor} deildi með {user}",
    "{actor} removed share for {user}" : "{actor} fjarlægði deilingu með {user}",
    "Shared by {actor}" : "Deilt af {actor}",
    "{actor} removed share" : "{actor} fjarlægði deilingu",
    "You shared {file} with {user}" : "Þú deildir {file} með {user}",
    "You removed {user} from {file}" : "Þú fjarlægðir {user} af {file}",
    "{actor} shared {file} with {user}" : "{actor} deildi {file} með {user}",
    "{actor} removed {user} from {file}" : "{actor} fjarlægði {user} af {file}",
    "{actor} shared {file} with you" : "{actor} deildi {file} með þér",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Skrá eða mappa sem deilt var með tölvupósti eða almenningstengli var <strong>sótt</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Skjali eða möppu hefur verið deilt <strong>frá öðrum þjóni</strong>",
    "A file or folder has been <strong>shared</strong>" : "Skjali eða  möppu hefur verið <strong>deilt</strong>",
    "Wrong share ID, share doesn't exist" : "Rangt auðkenni sameignar, sameign er ekki til",
    "could not delete share" : "tókst ekki að eyða sameign",
    "Could not delete share" : "Tókst ekki að eyða sameign",
    "Please specify a file or folder path" : "Tiltaktu skrá eða slóð á möppu",
    "Wrong path, file/folder doesn't exist" : "Röng slóð, skrá/mappa er ekki til",
    "Could not create share" : "Ekki tókst að búa til sameign",
    "invalid permissions" : "Ógildar aðgangsheimildir",
    "Please specify a valid user" : "Settu inn gilt notandanafn",
    "Group sharing is disabled by the administrator" : "Deiling innan hóps hefur verið gerð óvirk af kerfisstjóra.",
    "Please specify a valid group" : "Settu inn gildan hóp",
    "Public link sharing is disabled by the administrator" : "Deiling opinberra sameignartengla hefur verið gerð óvirk af kerfisstjóra.",
    "Public upload disabled by the administrator" : "Opinber innsending hefur verið gerð óvirk af kerfisstjóra.",
    "Public upload is only possible for publicly shared folders" : "Opinber innsending er einungis möguleg í möppur sem er deilt opinberlega",
    "Invalid date, date format must be YYYY-MM-DD" : "Ógild dagsetning, dagsetningasniðið verður að vera ÁÁÁÁ-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Deiling %s mistókst, því bakvinnslukerfið leyfir ekki sameignir af gerðinni %s",
    "You cannot share to a Circle if the app is not enabled" : "Þú getur ekki deilt með hring ef forritið er ekki virkt",
    "Please specify a valid circle" : "Settu inn gildan hring",
    "Unknown share type" : "Óþekkt tegund sameignar",
    "Not a directory" : "Er ekki mappa",
    "Could not lock path" : "Gat ekki læst slóð",
    "Wrong or no update parameter given" : "Rangt eða ekkert uppfærsluviðfang gefið",
    "Can't change permissions for public share links" : "Ekki tókst að breyta aðgangsheimildum fyrir opinbera deilingartengla",
    "Cannot increase permissions" : "Get ekki aukið aðgangsheimildir",
    "shared by %s" : "Deilt af %s",
    "Download" : "Niðurhal",
    "Direct link" : "Beinn tengill",
    "Add to your Nextcloud" : "Bæta í þitt eigið Nextcloud",
    "Share API is disabled" : "Deilingar-API er óvirkt",
    "File sharing" : "Skráadeiling",
    "No entries found in this folder" : "Engar skrár fundust í þessari möppu",
    "Name" : "Nafn",
    "Share time" : "Deilingartími",
    "Expiration date" : "Gildir til",
    "Sorry, this link doesn’t seem to work anymore." : "Því miður, þessi tengill virðist ekki virka lengur.",
    "Reasons might be:" : "Mögulegar ástæður gætu verið:",
    "the item was removed" : "atriðið var fjarlægt",
    "the link expired" : "tengillinn er útrunninn",
    "sharing is disabled" : "slökkt er á skráadeilingu",
    "For more info, please ask the person who sent this link." : "Til að vita meira skaltu hafa samband við þann sem sendi þér þennan tengil.",
    "Download %s" : "Sækja %s",
    "Upload files to %s" : "Senda inn skrár á %s",
    "Select or drop files" : "Veldu eða slepptu skrám",
    "Uploading files…" : "Sendi inn skrár…",
    "Uploaded files:" : "Innsendar skrár:",
    "{actor} removed you from {file}" : "{actor} fjarlægði þig af {file}",
    "%s is publicly shared" : "%s er deilt opinberlega",
    "This share is password-protected" : "Þessi sameign er varin með lykilorði",
    "The password is wrong. Try again." : "Lykilorðið er rangt. Reyndu aftur.",
    "Password" : "Lykilorð"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
